@@ -1,10 +1,9 @@
 import logging
-from typing import Any, Dict, List, Optional, Tuple
+from typing import Any, Dict, List, Optional
 
-from datayoga_core import utils
 from datayoga_core.context import Context
 from datayoga_core.job import Job
-from datayoga_core.result import Result
+from datayoga_core.result import JobResult
 
 logger = logging.getLogger("dy")
 
@@ -50,21 +49,20 @@ def validate(job_settings: Dict[str, Any], whitelisted_blocks: Optional[List[str
 def transform(job_settings: Dict[str, Any],
               data: List[Dict[str, Any]],
               context: Optional[Context] = None,
-              whitelisted_blocks: Optional[List[str]] = None) -> Tuple[List[Dict[str, Any]], List[Result]]:
+              whitelisted_blocks: Optional[List[str]] = None) -> JobResult:
     """
     Transforms data against a certain job
 
     Args:
         job_settings (Dict[str, Any]): Job settings
         data (List[Dict[str, Any]]): Data to transform
-        context (Optional[Context], optional): Context. Defaults to None.
-        whitelisted_blocks: (Optional[List[str]], optional): Whitelisted blocks. Defaults to None.
+        context (Optional[Context]): Context. Defaults to None.
+        whitelisted_blocks: (Optional[List[str]]): Whitelisted blocks. Defaults to None.
 
     Returns:
-        Tuple[List[Dict[str, Any]], List[Result]]: Transformed data and results
+        JobResult: Job result
     """
     job = compile(job_settings, whitelisted_blocks)
     job.init(context)
     logger.debug("Transforming data")
     return job.transform(data)
-
