@@ -15,6 +15,7 @@ from jsonschema import validate
 
 logger = logging.getLogger("dy")
 
+
 class Block(metaclass=ABCMeta):
     INTERNAL_FIELD_PREFIX = "__$$"
     MSG_ID_FIELD = f"{INTERNAL_FIELD_PREFIX}msg_id"
@@ -83,6 +84,12 @@ class Block(metaclass=ABCMeta):
         """
         pass
 
+    def stop(self):
+        """
+        Cleans the block connections and state
+        """
+        pass
+
     def get_block_name(self):
         return os.path.basename(os.path.dirname(sys.modules[self.__module__].__file__))
 
